@@ -180,8 +180,8 @@ class HttpResource(Resource):
             if is_json_mimetype(content_type):
                 return content_type, json.loads(self.body)
             elif content_type == "text/html":
-                return content_type, BeautifulSoup(self.body, "html5lib")
-            elif content_type == "text/xml":
+                return content_type, BeautifulSoup(self.body, "html.parser")
+            elif content_type == "text/xml" or content_type == "application/xml":
                 return content_type, BeautifulSoup(self.body, "lxml")
             else:
                 return content_type, None
@@ -545,7 +545,6 @@ class HttpResource(Resource):
     def __init__(self, *args, **kwargs):
         self.session = kwargs.pop("session", requests.Session())
         self.timeout = kwargs.pop("timeout", 30)
-        self.interval_duration = kwargs.pop("interval_duration", 0)
         super(HttpResource, self).__init__(*args, **kwargs)
 
     def clean(self):
